@@ -25,7 +25,7 @@ iterchoiceS1 <- function(n,mini,maxi,tUy,eigenvaluesS1,ddlmini,ddlmaxi,y,criteri
     }
     fraction <- c(fraction[1:(dep-1)],bb)
     for (i in 1:(length(fraction)-1)) {
-      res1 <- optimize(critS1gmdl,lower=fraction[i],upper=fraction[i+1],tol=0.5,valpr=eigenvaluesS1,tUy2=tUy2,n=n,ddlmini=ddlmini,ddlmaxi=ddlmaxi,Y=y)
+      res1 <- stats::optimize(critS1gmdl,lower=fraction[i],upper=fraction[i+1],tol=0.5,valpr=eigenvaluesS1,tUy2=tUy2,n=n,ddlmini=ddlmini,ddlmaxi=ddlmaxi,Y=y)
       if (res1$objective<res$objective) res <- res1
     }
   } else {
@@ -53,7 +53,7 @@ iterchoiceS1 <- function(n,mini,maxi,tUy,eigenvaluesS1,ddlmini,ddlmaxi,y,criteri
     }
     fraction <- c(fraction[1:(dep-1)],bb)
     for (i in 1:(length(fraction)-1)) {
-      res1 <- optimize(fcriterion,lower=fraction[i],upper=fraction[i+1],tol=0.5,valpr=eigenvaluesS1,tUy2=tUy2,n=n,ddlmini=ddlmini,ddlmaxi=ddlmaxi)
+      res1 <- stats::optimize(fcriterion,lower=fraction[i],upper=fraction[i+1],tol=0.5,valpr=eigenvaluesS1,tUy2=tUy2,n=n,ddlmini=ddlmini,ddlmaxi=ddlmaxi)
       if (res1$objective<res$objective) res <- res1
     }     
   }
